# copyright <sebas @ koumbit.org>
# copyright <josx @ interorganic.com.ar >
# Licence: GPL
#

class escritorio::gnome-theme::xp {
    $local_path = "/dist/svn-redcta"
    $local_name = "gnome-theme-xp"
    $jaunty_script = "change-default-to-xp.sh"
    $lucid_script = "lucid-escritorio-xp.sh"
    $jaunty_file_path = "$local_path/$local_name/$jaunty_script"
    $lucid_file_path =  "$local_path/$local_name/$lucid_script"

    case $operatingsystem {
        Ubuntu: {
            case $lsbdistcodename {
                Jaunty: {
                    $ejecuta = $jaunty_file_path
                }
                Lucid: {
                    $ejecuta = $lucid_file_path
                }
                default: {
                    err("No hay tema para $operatingsystem - $lsbdistcodename")
                }   
            }
        }
    }
   
    svn::checkout { gnome-theme-xp:
        repository => "https://svn.redcta.org.ar/proyectos/redcta/trunk/gnome-theme-xp",
        local_path => $local_path,
        local_name => $local_name,
        notify     => [ Exec["$ejecuta"] ],
        before     => [ File["$ejecuta"] , Exec["$ejecuta"] ],
    }

    file { "/dist/svn-redcta/gnome-theme-xp/change-default-to-xp.sh":
        ensure => "present",
        owner  => "root", group => "root", mode => "755", checksum => mtime,
    }

    file { "$lucid_file_path":
        ensure => "present",
        owner  => "root", group => "root", mode => "755", checksum => mtime,
    }

    #   Esto no deberia hacerse, solamente habria usar ejecutar, lo dejo por jaunty 
    #   ver changeset [643]
    #   falta poner refresh = true en lucid
    case $operatingsystem {
        Ubuntu: {
            case $lsbdistcodename {
                Jaunty: {
                    exec { "$jaunty_file_path":
                    refreshonly => true,
                    subscribe => File["/dist/svn-redcta/gnome-theme-xp/change-default-to-xp.sh"]
                    }
                }
                Lucid: {
                    exec { "$lucid_file_path":
                    refreshonly => true,
                    subscribe => File["$lucid_file_path"]
                    }
                }
                default: {
                    err("No hay tema para $operatingsystem - $lsbdistcodename")
                }   
            }
        }
        default: {
            err("No hay tema para $operatingsystem")
        }   
    }
}


class escritorio::iconos {

    package { [ "xdg-utils" ]: ensure => installed }
    
    # Modificamos el archivo xdg-desktop-icon porque solo funcionaba para el directorio Desktop      
    file { "/usr/bin/xdg-desktop-icon":
        owner   => root,
        group   => root,
        mode    => 755,
        source  => "puppet:///escritorio/xdg/xdg-desktop-icon",
        require => Package["xdg-utils"]
    }

    file  { "/etc/X11/Xsession.d/65xdg-user-desktop-icons-update":
        ensure => "/dist/svn-redcta/gnome-theme-xp/Xsession.d/65xdg-user-desktop-icons-update"
    }

}


class escritorio::fondos::cta {

    svn::checkout { escritorio-fondos-cta:
        repository => "https://svn.redcta.org.ar/proyectos/redcta/trunk/escritorio-fondos-cta",
        local_path => "/dist/svn-redcta",
        local_name => "escritorio-fondos-cta"
    }

    file  { "/usr/share/backgrounds/wpiedras-hojitas.jpg":
        ensure => "/dist/svn-redcta/escritorio-fondos-cta/wpiedras-hojitas.jpg"
    }

    file { "/usr/share/backgrounds/wpiedras-verdecito.jpg":
        ensure => "/dist/svn-redcta/escritorio-fondos-cta/wpiedras-verdecito.jpg"
    }
}


class escritorio::autostart-off {

    define deshabilita_servicios($archivos) {
        deshabilita_servicio { $archivos: archivo => $name }
    }

    define habilita_servicios($archivos) {
        habilita_servicio { $archivos: archivo => $name }
    }

   define deshabilita_servicio($archivo) {
        file { "${archivo}/$name"  : ensure => present, }

        line { "verdadero$name" :
            file   => "${archivo}/$name",
            line   => "X-GNOME-Autostart-enabled=true",
            ensure => absent,
        }
        line { "falso$name":
            file   => "${archivo}/$name" ,
            line   => "X-GNOME-Autostart-enabled=false",
            ensure => present,
        }
    }

    define habilita_servicio($archivo) {
        file { "${archivo}/$name"  : ensure => present, }

        line { "falso$name":
            file   => "${archivo}/$name" ,
            line   => "X-GNOME-Autostart-enabled=false",
            ensure => absent,
        }
        line { "verdadero$name" :
            file   => "${archivo}/$name",
            line   => "X-GNOME-Autostart-enabled=true",
            ensure => present,
        }
 
    }

    case $operatingsystem {
    Ubuntu: {
        case $lsbdistcodename {
            Jaunty: {
                deshabilita_servicios { "/etc/xdg/autostart":
                    archivos => [ "vino-server.desktop", "update-notifier.desktop", "bluetooth-applet.desktop", "evolution-alarm-notify.desktop", "jockey-gtk.desktop", "gnome-at-session.desktop", "gnome-power-manager.desktop" ],
                }
            }  
            Lucid: {
                deshabilita_servicios { "/etc/xdg/autostart":
                    archivos => [ "at-spi-registryd.desktop", "bluetooth-applet.desktop", "gwibber.desktop", "evolution-alarm-notify.desktop",  "indicator-applet.desktop", "gdu-notification-daemon.desktop",  "jockey-gtk.desktop", "gnome-at-session.desktop", "gnome-keyring-pkcs11.desktop", "polkit-gnome-authentication-agent-1.desktop", "gnome-keyring-secrets.desktop", "polkit-kde-authentication-agent-1.desktop", "gnome-keyring-ssh.desktop", "print-applet.desktop", "gnome-power-manager.desktop", "pulseaudio.desktop", "update-notifier.desktop", "vino-server.desktop", "user-dirs-update-gtk.desktop", "gnome-user-share.desktop" ],
                }

		habilita_servicios { "/etc/xdg/autostart": archivos => ["nm-applet.desktop","gnome-volume-control-applet.desktop"] }
            }
            default: {
                err("No hay deshabilitacion de servicios para $opertatingsystem - $lsbdistcodename")
            }
        }
    }
    default: {
        err("No hay deshabilitacion de servicios para $operatingsystem")    
    }
    }   
}

